==> cscec5b-rmat-api-3.0.1-20221110.031426-84-sources.jar: com/ejianc/business/rmat/vo/CalculateOtherVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 租金计算单-其他费用
 * 
 * @author generator
 * 
 */
public class CalculateOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long calculateId; // 结算id
    private Long sourceId; // 来源数据Id
    private Integer sourceType; // 来源类型：0-新增，1-合同代入
    private String costName; // 费用名称
    private BigDecimal unitTaxPrice; // 单价
    private BigDecimal unitPrice; // 单价(无税)
    private BigDecimal num; // 数量
    private BigDecimal taxRate; // 税率
    private BigDecimal taxMny; // 本期金额
    private BigDecimal mny; // 本期金额(无税)
    private BigDecimal tax; // 税额
    private String memo; // 备注
    

    public Long getCalculateId() {
        return calculateId;
    }

    public void setCalculateId(Long calculateId) {
        this.calculateId = calculateId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-rmat-api-3.0.1-20230804.081751-239-sources.jar: com/ejianc/business/rmat/vo/CalculateOtherVO.java <==
package com.ejianc.business.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 租金计算单-其他费用
 *
 * @author generator
 *
 */
public class CalculateOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long calculateId; // 结算id
    private Long sourceId; // 来源数据Id
    private Integer sourceType; // 来源类型：0-新增，1-合同代入
    private String costName; // 费用名称
    private BigDecimal unitTaxPrice; // 单价
    private BigDecimal unitPrice; // 单价(无税)
    private BigDecimal num; // 数量
    private BigDecimal taxRate; // 税率
    private BigDecimal taxMny; // 本期金额
    private BigDecimal mny; // 本期金额(无税)
    private BigDecimal tax; // 税额
    private String memo; // 备注

    private String pkAmountlist; // 分录主键
    private String htywnr; // 分录名称


    public Long getCalculateId() {
        return calculateId;
    }

    public void setCalculateId(Long calculateId) {
        this.calculateId = calculateId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }


    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }
}
